import { useRef } from "react";
import { useLink, useMount, useScript } from "../../hook";
import "./index.less";

interface IVideo {
  fileID: string;
  appID: string;
  psign?: string;
}

/**
 * demo页面：https://tcplayer.vcube.tencent.com/
 * 
 * 如果需要在 Chrome 和 Firefox 等现代浏览器中通过 H5 播放 Webrtc 视频, 需要在 tcplayer.vx.x.x.min.js 之前引入 TXLivePlayer-x.x.x.min.js。
 * 有些浏览器环境不支持 Webrtc，播放器会将 Webrtc 流地址自动转换为 HLS 格式地址，因此快直播场景同样需要引入hls.min.x.xx.xm.js。
 * <video objectFill /> fill填满变形，cover等比例会裁剪, contain等比例有黑边
 */
function Player() {
  const playerRef = useRef<any>();

  useLink(["/player/tcplayer_pure.min.css"]);
  useScript(
    ["/player/libs/hls.min.0.13.2m.js", "/player/tcplayer.v4.7.2.min.js"],
    () => {
      const TCPlayer = (window as any).TCPlayer;

      // 重写播放按钮
      const Button = TCPlayer.getComponent("Button");
      const BigPlayButton = TCPlayer.getComponent("BigPlayButton");
      BigPlayButton.prototype.createEl = function () {
        const el = Button.prototype.createEl.call(this);
        const _html =
          '<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" viewBox="0 0 1024 1024"><path d="M512 64C264.6 64 64 264.6 64 512s200.6 448 448 448s448-200.6 448-448S759.4 64 512 64zm0 820c-205.4 0-372-166.6-372-372s166.6-372 372-372s372 166.6 372 372s-166.6 372-372 372z" fill-opacity=".8" fill="currentColor"></path><path d="M512 140c-205.4 0-372 166.6-372 372s166.6 372 372 372s372-166.6 372-372s-166.6-372-372-372zm164.1 378.2L457.7 677.1a8.02 8.02 0 0 1-12.7-6.5V353a8 8 0 0 1 12.7-6.5l218.4 158.8a7.9 7.9 0 0 1 0 12.9z" fill-opacity=".1" fill="currentColor"></path><path d="M676.1 505.3L457.7 346.5A8 8 0 0 0 445 353v317.6a8.02 8.02 0 0 0 12.7 6.5l218.4-158.9a7.9 7.9 0 0 0 0-12.9z" fill-opacity=".8" fill="currentColor"></path></svg>';
        el.appendChild(
          TCPlayer.dom.createEl("div", {
            className: "vjs-button-icon-custom",
            innerHTML: _html,
          })
        );
        return el;
      };
      playerRef.current = TCPlayer("player", {
        fileID: "243791579995468466",
        appID: "1500018521",
        //私有加密播放需填写 psign， psign 即播放器签名，签名介绍和生成方式参见链接：https://cloud.tencent.com/document/product/266/42436
        //psign:'eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJhcHBJZCI6MTUwMDAwNTY5NiwiZmlsZUlkIjoiMzcwMTkyNTkyMTI5OTYzNzAxMCIsImN1cnJlbnRUaW1lU3RhbXAiOjE2MjY4NjAxNzYsImV4cGlyZVRpbWVTdGFtcCI6MjYyNjg1OTE3OSwicGNmZyI6InByaXZhdGUiLCJ1cmxBY2Nlc3NJbmZvIjp7InQiOiI5YzkyYjBhYiJ9LCJkcm1MaWNlbnNlSW5mbyI6eyJleHBpcmVUaW1lU3RhbXAiOjI2MjY4NTkxNzksInN0cmljdE1vZGUiOjJ9fQ.Bo5K5ThInc4n8AlzIZQ-CP9a49M2mEr9-zQLH9ocQgI',
      });
    }
  );

  /**
   * 切换视频
   */
  const changeVideo = (video: IVideo) => {
    playerRef.current!.loadVideoByID({ ...video });
  };

  return (
    <div className="player-container">
      <video
        onContextMenu={(e) => e.preventDefault()}
        id="player"
        style={{ width: "100%", height: "100%", objectFit: "contain" }}
        preload="auto"
        playsInline
      ></video>
    </div>
  );
}

export default Player;
